Documentation
¶
Overview ¶
Package encoding defines interfaces shared by other packages that convert data to and from byte-level and textual representations. The interfaces come in pairs that produce and consume encoded data.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BinaryAppender ¶
type BinaryAppender interface {
// AppendBinary appends the binary representation of itself to the end of b
// (allocating a larger slice if necessary) and returns the updated slice.
//
// Implementations must not retain b, nor mutate any bytes within b[:len(b)].
AppendBinary(b []byte) ([]byte, error)
}
BinaryAppender is the interface implemented by an object that can append the binary representation of itself. If a type implements both BinaryAppender and BinaryMarshaler, then v.MarshalBinary() must be semantically identical to v.AppendBinary(nil).
type BinaryMarshaler ¶
BinaryMarshaler is the interface implemented by an object that can marshal itself into a binary form.
MarshalBinary encodes the receiver into a binary form and returns the result.
type BinaryUnmarshaler ¶
BinaryUnmarshaler is the interface implemented by an object that can unmarshal a binary representation of itself.
UnmarshalBinary must be able to decode the form generated by MarshalBinary. UnmarshalBinary must copy the data if it wishes to retain the data after returning.
type TextAppender ¶
type TextAppender interface {
// AppendText appends the textual representation of itself to the end of b
// (allocating a larger slice if necessary) and returns the updated slice.
//
// Implementations must not retain b, nor mutate any bytes within b[:len(b)].
AppendText(b []byte) ([]byte, error)
}
TextAppender is the interface implemented by an object that can append the textual representation of itself. If a type implements both TextAppender and TextMarshaler, then v.MarshalText() must be semantically identical to v.AppendText(nil).
type TextMarshaler ¶
TextMarshaler is the interface implemented by an object that can marshal itself into a textual form.
MarshalText encodes the receiver into UTF-8-encoded text and returns the result.
type TextUnmarshaler ¶
TextUnmarshaler is the interface implemented by an object that can unmarshal a textual representation of itself.
UnmarshalText must be able to decode the form generated by MarshalText. UnmarshalText must copy the text if it wishes to retain the text after returning.